pub enum Error {
AlreadyJoined {
name: &'static str,
},
EmptyFleet,
CacheFrameTooLarge {
key_len: usize,
value_len: usize,
max_payload: usize,
},
EventFrameTooLarge {
topic_len: usize,
payload_len: usize,
max_payload: usize,
},
ContestFrameTooLarge {
subject_len: usize,
owner_len: usize,
max_payload: usize,
},
Io(Error),
}Variants
AlreadyJoined
Fleet::join was called twice in the same process.
EmptyFleet
Fleet size cannot be zero — Orbit’s plurality requirement (see VISION 2).
CacheFrameTooLarge
A cache frame could not fit into the current ring payload.
EventFrameTooLarge
An event frame could not fit into the current ring payload.
ContestFrameTooLarge
A contest frame could not fit into the current ring payload.
Io(Error)
Shared-memory ring operation failed.