pub struct OrbitEventCursor { /* private fields */ }Expand description
Cursor for one event subscriber.
The cursor stores the next ring counter the subscriber should try to read. It is intentionally caller-owned so different consumers can advance independently.
Implementations
Sourceimpl OrbitEventCursor
impl OrbitEventCursor
Sourcepub const fn from_start() -> Self
pub const fn from_start() -> Self
Start from the beginning of the ring history that is still available.
Sourcepub const fn from_counter(next_counter: u64) -> Self
pub const fn from_counter(next_counter: u64) -> Self
Start from a known next counter.
Sourcepub const fn next_counter(self) -> u64
pub const fn next_counter(self) -> u64
The next counter this cursor will read.