pub struct OrbitEventPoll {
pub events: Vec<OrbitEvent>,
pub lagged: u64,
}Expand description
Result of polling an event cursor.
Fields
events: Vec<OrbitEvent>lagged: u64Number of counters that could not be delivered because the subscriber lagged past the ring capacity, a slot was empty, or a slot had already wrapped to another counter.
Implementations